pub struct AggregateSetBuilder<'a> { /* private fields */ }Expand description
Collects aggregate overloads into a function set (see
Connection::register_aggregate_function_set).
Implementations
Sourceimpl AggregateSetBuilder<'_>
impl AggregateSetBuilder<'_>
Sourcepub fn add<A: VAggregate>(&mut self) -> Result<&mut Self>
pub fn add<A: VAggregate>(&mut self) -> Result<&mut Self>
Adds overload A (with a default shared state) to the set.
Errors
Returns an error if a logical type cannot be built or the overload conflicts with one already in the set.
Sourcepub fn add_with_state<A: VAggregate>(
&mut self,
shared: A::Shared,
) -> Result<&mut Self>
pub fn add_with_state<A: VAggregate>( &mut self, shared: A::Shared, ) -> Result<&mut Self>